import 'package:flutter/material.dart';

import 'package:wordguessing/config/default_game_settings.dart';
import 'package:wordguessing/models/settings/settings_game.dart';
import 'package:wordguessing/models/settings/settings_global.dart';
import 'package:wordguessing/ui/helpers/styled_button.dart';
import 'package:wordguessing/utils/tools.dart';

class ParameterWidget extends StatelessWidget {
  const ParameterWidget({
    super.key,
    required this.code,
    required this.value,
    required this.isSelected,
    required this.size,
    required this.gameSettings,
    required this.globalSettings,
    required this.onPressed,
  });

  final String code;
  final String value;
  final bool isSelected;
  final double size;
  final GameSettings gameSettings;
  final GlobalSettings globalSettings;
  final VoidCallback onPressed;

  static const Color buttonColorActive = Colors.blue;
  static const Color buttonColorInactive = Colors.white;
  static const double buttonBorderWidth = 4.0;
  static const double buttonBorderRadius = 12.0;

  @override
  Widget build(BuildContext context) {
    Widget content = const SizedBox.shrink();

    switch (code) {
      case DefaultGameSettings.parameterCodeGameType:
        content = getGameTypeParameterItem();
        break;
      case DefaultGameSettings.parameterCodeLangValue:
        content = getLangValueParameterItem();
        break;
      default:
        printlog('Unknown parameter: $code/$value');
        content = getUnknownParameterItem();
    }

    final Color buttonColor = isSelected ? buttonColorActive : buttonColorInactive;

    return Container(
      decoration: BoxDecoration(
        color: buttonColor,
        borderRadius: BorderRadius.circular(buttonBorderRadius),
        border: Border.all(
          color: buttonColor,
          width: buttonBorderWidth,
        ),
      ),
      child: content,
    );
  }

  // "unknown" parameter -> simple block with text
  Widget getUnknownParameterItem() {
    return StyledButton.text(
      caption: '$code / $value',
      color: Colors.grey,
      onPressed: null,
    );
  }

  Widget getGameTypeParameterItem() {
    const Color backgroundColor = Colors.teal;

    return StyledButton(
      color: backgroundColor,
      onPressed: onPressed,
      child: Image(
        image: AssetImage('assets/ui/${DefaultGameSettings.parameterCodeGameType}_$value.png'),
        fit: BoxFit.fill,
      ),
    );
  }

  Widget getLangValueParameterItem() {
    const Color backgroundColor = Colors.teal;

    String text = '';

    switch (value) {
      case DefaultGameSettings.langValueFr:
        text = '🇫🇷';
        break;
      case DefaultGameSettings.langValueEn:
        text = '🇬🇧';
        break;
      default:
        printlog('Wrong value for lang parameter value: $value');
    }

    return StyledButton(
      color: backgroundColor,
      onPressed: onPressed,
      child: Text(
        text,
        style: TextStyle(
          fontSize: 70,
        ),
      ),
    );
  }
}
