import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import 'package:wordguessing/config/default_game_settings.dart';
import 'package:wordguessing/cubit/game_cubit.dart';
import 'package:wordguessing/models/data/word.dart';
import 'package:wordguessing/models/game/game.dart';
import 'package:wordguessing/ui/widgets/game/pick_image_game_image.dart';

class PickImageGameItemsContainer extends StatelessWidget {
  const PickImageGameItemsContainer({super.key});

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<GameCubit, GameState>(
      builder: (BuildContext context, GameState gameState) {
        final Game currentGame = gameState.currentGame;
        final List<Word> images = currentGame.images;

        if (images.length != DefaultGameSettings.itemsCount) {
          return const SizedBox.shrink();
        }

        images.sort((a, b) => a.key.compareTo(b.key));

        return Column(
          mainAxisSize: MainAxisSize.min,
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            Row(
              mainAxisSize: MainAxisSize.min,
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                PickImageGameImageContainer(word: images[0]),
                PickImageGameImageContainer(word: images[1]),
              ],
            ),
            Row(
              mainAxisSize: MainAxisSize.min,
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                PickImageGameImageContainer(word: images[2]),
                PickImageGameImageContainer(word: images[3]),
              ],
            )
          ],
        );
      },
    );
  }
}
